==> nextcloud-16.0.5.tgz: nextcloud/apps/federatedfilesharing/l10n/ia.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Esque tu vole adder le Compartir Remote {name} de {owner}@{remote}?",
    "Remote share" : "Compartir Remote",
    "Remote share password" : "Contrasigno del Compartir Remote",
    "Cancel" : "Cancellar",
    "Add remote share" : "Adder le Compartir Remote",
    "Copy" : "Copiar",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "Invalid Federated Cloud ID" : "ID del Nube Federate",
    "Server to server sharing is not enabled on this server" : "Le Compartir de Servitor a Servitor non es activate in iste servitor",
    "Couldn't establish a federated share." : "Impossibile establir le Compartir Federate.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile establir le Compartir Federate, possibilemente le contrasigno esseva incorrecte.",
    "Not allowed to create a federated share with the same user" : "Il non es permittite crear le Compartir Federate con le mesme usator.",
    "File is already shared with %s" : "File ja es compartite con %s",
    "Could not find share" : "Impossibile trovar le compartite",
    "Federated sharing" : "Compartir Federate",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Tu recipeva \"%3$s\" como un compartimento remote de %1$s (in nomine de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Tu recipeva {share} como un compartimento remote de {user} (in nomine de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Tu recipeva \"%3$s\" como un compartimento remote de %1$s",
    "You received {share} as a remote share from {user}" : "Tu recipeva {share} como un compartimento remote de {user}",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Comparti con me per mi ID de Nube Federate #Nextcloud, vide %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparti con me per mi ID de Nube Federate #Nextcloud",
    "Federated Cloud Sharing" : "Compartimento del Nube Federate",
    "Open documentation" : "Documentation aperte",
    "Allow users on this server to send shares to other servers" : "Permitter usatores in iste servitor a inviar elementos compartite a altere servitores",
    "Allow users on this server to receive shares from other servers" : "Permitter usatores in iste servitor a reciper elementos compartite ex altere servitores",
    "Search global and public address book for users" : "Cercar pro usatores in adressarios global e public",
    "Federated Cloud" : "Nube Federate",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federate:",
    "Add to your website" : "Adde a tu sito web",
    "Share with me via Nextcloud" : "Comparti con me via Nextcloud",
    "HTML Code:" : "Codice HTML:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.3.tgz: nextcloud/apps/federatedfilesharing/l10n/ia.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Esque tu vole adder le Compartir Remote {name} de {owner}@{remote}?",
    "Remote share" : "Compartir Remote",
    "Remote share password" : "Contrasigno del Compartir Remote",
    "Cancel" : "Cancellar",
    "Add remote share" : "Adder le Compartir Remote",
    "Copy" : "Copiar",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "Invalid Federated Cloud ID" : "ID del Nube Federate",
    "Server to server sharing is not enabled on this server" : "Le Compartir de Servitor a Servitor non es activate in iste servitor",
    "Couldn't establish a federated share." : "Impossibile establir le Compartir Federate.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile establir le Compartir Federate, possibilemente le contrasigno esseva incorrecte.",
    "Not allowed to create a federated share with the same user" : "Il non es permittite crear le Compartir Federate con le mesme usator.",
    "File is already shared with %s" : "File ja es compartite con %s",
    "Could not find share" : "Impossibile trovar le compartite",
    "Federated sharing" : "Compartir Federate",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Tu recipeva {share} como un compartimento remote de {user} (in nomine de {behalf})",
    "You received {share} as a remote share from {user}" : "Tu recipeva {share} como un compartimento remote de {user}",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Comparti con me per mi ID de Nube Federate #Nextcloud, vide %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparti con me per mi ID de Nube Federate #Nextcloud",
    "Sharing" : "Compartente",
    "Federated Cloud Sharing" : "Compartimento del Nube Federate",
    "Open documentation" : "Documentation aperte",
    "Allow users on this server to send shares to other servers" : "Permitter usatores in iste servitor a inviar elementos compartite a altere servitores",
    "Allow users on this server to receive shares from other servers" : "Permitter usatores in iste servitor a reciper elementos compartite ex altere servitores",
    "Search global and public address book for users" : "Cercar pro usatores in adressarios global e public",
    "Federated Cloud" : "Nube Federate",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federate:",
    "Add to your website" : "Adde a tu sito web",
    "Share with me via Nextcloud" : "Comparti con me via Nextcloud",
    "HTML Code:" : "Codice HTML:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Tu recipeva \"%3$s\" como un compartimento remote de %1$s (in nomine de %2$s)",
    "You received \"%3$s\" as a remote share from %1$s" : "Tu recipeva \"%3$s\" como un compartimento remote de %1$s"
},
"nplurals=2; plural=(n != 1);");
